@@ -1,6 +1,7 @@
-/* utf8convert.cc: convert a string to UTF-8 encoding.
- *
- * Copyright (C) 2006,2007,2008,2010,2013,2017 Olly Betts
+/** @file utf8convert.cc
+ * @brief convert a string to UTF-8 encoding.
+ */
+/* Copyright (C) 2006,2007,2008,2010,2013,2017,2019 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +43,8 @@ convert_to_utf8(string & text, const string & charset)
 	return;
     if (charset.size() == 4 && strcasecmp(charset.c_str(), "utf8") == 0)
 	return;
+    if (charset.size() == 8 && strcasecmp(charset.c_str(), "us-ascii") == 0)
+	return;
 
     // Nobody has told us what charset it's in, so do as little work as
     // possible!
